@@ -8,16 +8,18 @@ The project object is the central import point of pyiron - all other objects can
 import os
 import posixpath
 import shutil
+from tqdm import tqdm
 import pandas
 import importlib
 import numpy as np
 import pkgutil
 from git import Repo, InvalidGitRepositoryError
-
+from warnings import warn
 from pyiron_base.project.path import ProjectPath
 from pyiron_base.database.filetable import FileTable
 from pyiron_base.settings.generic import Settings
 from pyiron_base.settings.publications import list_publications
+from pyiron_base.database.performance import get_database_statistics
 from pyiron_base.database.jobtable import (
     get_db_columns,
     get_job_ids,
@@ -46,7 +48,6 @@ from pyiron_base.server.queuestatus import (
 )
 from pyiron_base.job.external import Notebook
 from pyiron_base.project.data import ProjectData
-
 from pyiron_base.archiving import import_archive, export_archive
 
 __author__ = "Joerg Neugebauer, Jan Janssen"
@@ -130,6 +131,14 @@ class Project(ProjectPath, HasGroups):
             self.db = FileTable(project=path)
         self.job_type = JobTypeChoice()
 
+        self._maintenance = None
+
+    @property
+    def maintenance(self):
+        if self._maintenance is None:
+            self._maintenance = Maintenance()
+        return self._maintenance
+
     @property
     def parent_group(self):
         """
@@ -522,7 +531,7 @@ class Project(ProjectPath, HasGroups):
         """
         return self.load(job_specifier=job_specifier, convert_to_object=False)
 
-    def iter_jobs(self, path=None, recursive=True, convert_to_object=True, status=None, job_type=None):
+    def iter_jobs(self, path=None, recursive=True, convert_to_object=True, status=None, job_type=None, progress=True):
         """
         Iterate over the jobs within the current project and it is sub projects
 
@@ -532,6 +541,7 @@ class Project(ProjectPath, HasGroups):
             convert_to_object (bool): load the full GenericJob object (default) or just the HDF5 / JobCore object
             status (str/None): status of the jobs to filter for - ['finished', 'aborted', 'submitted', ...]
             job_type (str/None): job type to filter for, corresponds to the 'hamilton' column in the job table
+            progress (bool): if True (default), add an interactive progress bar to the iteration
 
         Returns:
             yield: Yield of GenericJob or JobCore
@@ -549,6 +559,8 @@ class Project(ProjectPath, HasGroups):
                 if job_type is not None:
                     mask &= df["hamilton"] == job_type
                 job_id_lst = list(df[mask]["id"])
+        if progress:
+            job_id_lst = tqdm(job_id_lst)
         for job_id in job_id_lst:
             if path is not None:
                 yield self.load(job_id, convert_to_object=False)[path]
@@ -1505,6 +1517,85 @@ class Project(ProjectPath, HasGroups):
             self, archive_directory=origin_path, df=df, compressed=compress
         )
 
+    @classmethod
+    def register_tools(cls, name: str, tools):
+        """
+        Add a new creator to the project class.
+
+        Example)
+        
+        >>> from pyiron_base import Project, Toolkit
+        >>> class MyTools(Toolkit):
+        ...     @property
+        ...     def foo(self):
+        ...         return 'foo'
+        >>>
+        >>> Project.register_tools('my_tools', MyTools)
+        >>> pr = Project('scratch')
+        >>> print(pr.my_tools.foo)
+        'foo'
+
+        The intent is then that pyiron submodules (e.g. `pyiron_atomistics`) define a new creator and in their
+        `__init__.py` file only need to invoke `Project.register_creator('pyiron_submodule', SubmoduleCreator)`.
+        Then whenever `pyiron_submodule` gets imported, all its functionality is available on the project.
+
+        Args:
+            name (str): The name for the newly registered property.
+            tools (Toolkit): The tools to register.
+        """
+        if hasattr(cls, name):
+            raise AttributeError(
+                f'{cls.__name__} already has an attribute {name}. Please use a new name for registration.'
+            )
+        setattr(cls, name, property(lambda self: tools(self)))
+
+
+class Maintenance:
+    """
+    The purpose of maintenance class is to provide
+    some measures of perfomance for pyiron, whether local to the project
+    or global (describing the status of pyiron on the running machine)
+    """
+    def __init__(self):
+        """
+        initialize the local and global attributes
+        """
+        self._global = GlobalMaintenance()
+        self._local = None
+
+    @property
+    def global_status(self):
+        return self._global
+
+
+class GlobalMaintenance:
+    def __init__(self):
+        """
+        initialize the flag self._check_postgres, to control whether pyiron is
+        set to communicate with a postgres database.
+        """
+        s = Settings()
+        connection_string = s._configuration['sql_connection_string']
+        if "postgresql" not in connection_string:
+            warn(
+                """
+                The detabase statistics is only available for a Postgresql database
+                """
+            )
+            self._check_postgres = False
+        else:
+            self._check_postgres = True
+
+    def get_database_statistics(self):
+        if self._check_postgres:
+            return get_database_statistics()
+        else:
+            raise RuntimeError(
+                """
+                The detabase statistics is only available for a Postgresql database
+                """
+            )
+
 
 class Creator:
     def __init__(self, project):
